use strict;
package Simple;
# ABSTRACT: this is just a test

=head1 DESCRIPTION

This is a test.  How many times do I need to tell you that?

=synopsis

  use Test::Example::Pod q(uisp);

  uisp('q');

=head2 Free Radical

=head3 Subsumed Radical

=over 4

=item * nom nom nom list

=back

=method none

Nope, there are no methods.

=attr also_none

None of these, either.

=method i_lied

Ha!  Gotcha!

=cut

sub i_lied { ... }

1;
